# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/image/uncompressed/image_rgba.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3make87_messages/image/uncompressed/image_rgba.proto\x12\"make87_messages.image.uncompressed\x1a!make87_messages/core/header.proto\"\xdf\x01\n\tImageRGBA\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\x43\n\x06pixels\x18\x04 \x03(\x0b\x32\x33.make87_messages.image.uncompressed.ImageRGBA.Pixel\x1a@\n\x05Pixel\x12\x0b\n\x03red\x18\x01 \x01(\r\x12\r\n\x05green\x18\x02 \x01(\r\x12\x0c\n\x04\x62lue\x18\x03 \x01(\r\x12\r\n\x05\x61lpha\x18\x04 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.image.uncompressed.image_rgba_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IMAGERGBA']._serialized_start=127
  _globals['_IMAGERGBA']._serialized_end=350
  _globals['_IMAGERGBA_PIXEL']._serialized_start=286
  _globals['_IMAGERGBA_PIXEL']._serialized_end=350
# @@protoc_insertion_point(module_scope)
